Exception: MCPClient::Errors::AmbiguousPromptName
- Defined in:
- lib/mcp_client/errors.rb
Overview
Raised when multiple prompts with the same name exist across different servers
Raised when multiple prompts with the same name exist across different servers