Class: MCPClient::SchemaValidator::Context

Inherits:
Struct
  • Object
show all
Defined in:
lib/mcp_client/schema_validator.rb

Overview

Per-validation state. scope is the dynamic scope: the schema resources the evaluation has entered, outermost first, which is what a dynamic reference binds against (JSON Schema 2020-12 Core Section 8.2.3.2).

Instance Attribute Summary collapse

Instance Attribute Details

#anchors ⇒ Object

Returns the value of attribute anchors

Returns:

  • (Object) —

    the current value of anchors



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def anchors
  @anchors
end

#deadline ⇒ Object

Returns the value of attribute deadline

Returns:

  • (Object) —

    the current value of deadline



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def deadline
  @deadline
end

#depth ⇒ Object

Returns the value of attribute depth

Returns:

  • (Object) —

    the current value of depth



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def depth
  @depth
end

#dialect ⇒ Object

Returns the value of attribute dialect

Returns:

  • (Object) —

    the current value of dialect



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def dialect
  @dialect
end

#errors ⇒ Object

Returns the value of attribute errors

Returns:

  • (Object) —

    the current value of errors



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def errors
  @errors
end

#root ⇒ Object

Returns the value of attribute root

Returns:

  • (Object) —

    the current value of root



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def root
  @root
end

#scope ⇒ Object

Returns the value of attribute scope

Returns:

  • (Object) —

    the current value of scope



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def scope
  @scope
end

#speculative ⇒ Object

Returns the value of attribute speculative

Returns:

  • (Object) —

    the current value of speculative



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def speculative
  @speculative
end

#undecided ⇒ Object

Returns the value of attribute undecided

Returns:

  • (Object) —

    the current value of undecided



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def undecided
  @undecided
end

#visits ⇒ Object

Returns the value of attribute visits

Returns:

  • (Object) —

    the current value of visits



277
278
279
# File 'lib/mcp_client/schema_validator.rb', line 277

def visits
  @visits
end